@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 #
 #	Copyright (C) 2003-2010 Daniel Naber, Lutz Haseloff
-#	Copyright (C) 2013-2015 Mechtilde Stehmann
+#	Copyright (C) 2013-2018 Mechtilde Stehmann
 #
-#	Copyright (C) 2013-2015 for the gettext integration: Dr. Michael Stehmann
+#	Copyright (C) 2013-2016 for the gettext integration: Dr. Michael Stehmann
 #
 #	This program is free software; you can redistribute it and/or
 #	modify it under the terms of the GNU General Public License
@@ -213,7 +213,7 @@ class Application(object):
 		"""Start OOo to view the file. This method lacks 
 		error handling (TODO)."""
 		items = event.widget.curselection()
-		filename = os.path.join(self.search_path.get(), event.widget.get(items[0]))
+		filename = "%s%s" % (self.search_path.get(), event.widget.get(items[0]))
 		filename = os.path.normpath(filename)
 		prg = self.ooo_path.get()
 		if not prg:
@@ -566,7 +566,7 @@ class TranslationIntegration(object):
 
 if __name__ == "__main__":
 
-	version = "0.8.5"
+	version = "0.8.6"
 	loookversion = "loook-" + version
 	
 	g = TranslationIntegration(loookversion) 
